Coverage for /root/GitHubProjects/impacket/impacket/version.py: 60%

# Coverage for /root/GitHubProjects/impacket/impacket/version.py : 60%

## 10 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Impacket - Collection of Python classes for working with network protocols.

2#

3# SECUREAUTH LABS. Copyright (C) 2021 SecureAuth Corporation. All rights reserved.

4#

5# This software is provided under a slightly modified version

6# of the Apache Software License. See the accompanying LICENSE file

7# for more information.

8#

9

10 import pkg_resources

11 from impacket import __path__

12

13

14 try:

15 version = pkg_resources.get_distribution('impacket').version

16 except pkg_resources.DistributionNotFound:

17 version = "?"

18 print("Cannot determine Impacket version. "

19 "If running from source you should at least run \"python setup.py egg_info\"")

20 BANNER = "Impacket v{} - Copyright 2021 SecureAuth Corporation\n".format(version)

21

22 def getInstallationPath():

23 return 'Impacket Library Installation Path: {}'.format(__path__[0])